@@ -41,8 +41,8 @@ extern "C" {
 
 #define CS_VER 4  /* CXSparse Version */
 #define CS_SUBVER 0
-#define CS_SUBSUB 0
-#define CS_DATE "Nov 12, 2022"        /* CXSparse release date */
+#define CS_SUBSUB 2
+#define CS_DATE "Dec 9, 2022"        /* CXSparse release date */
 #define CS_COPYRIGHT "Copyright (c) Timothy A. Davis, 2006-2022"
 #define CXSPARSE
 
